# InowasFlopyAdapter

This library is used as a Flopy-Wrapper on the INOWAS-Platform.

More information will follow shortly.

## For developers

1. clone this
2. create a new environment
3. run `pip install .` to get all packages installed


## Run tests

There is a makefile provided to run the tests


  